from bluer_objects.README.items import ImageItems

from bluer_ugv.README.arzhang.consts import arzhang_assets2
from bluer_ugv.README.swallow.consts import swallow_assets2

items = ImageItems(
    {
        f"{arzhang_assets2}/20250722_174115-2.jpg": "",
        f"{arzhang_assets2}/20250825_190410.jpg": "",
        f"{arzhang_assets2}/20250825_190439.jpg": "",
        f"{arzhang_assets2}/20250825_190450.jpg": "",
        f"{arzhang_assets2}/20250825_190512.jpg": "",
        f"{arzhang_assets2}/20250830_125608.jpg": "",
        f"{arzhang_assets2}/20250830_125643.jpg": "",
        f"{arzhang_assets2}/20250830_132019.jpg": "",
        f"{arzhang_assets2}/VID-20250830-WA0000~3_1.gif": "",
        f"{arzhang_assets2}/20250901_105247.jpg": "",
        f"{arzhang_assets2}/20250905_120625.jpg": "",
        f"{arzhang_assets2}/VID-20250905-WA0014_1.gif": "../validations/village-1.md",
        f"{swallow_assets2}/20251001_185852.jpg": "",
        f"{swallow_assets2}/20251003_113240-2.jpg": "",
        f"{swallow_assets2}/20251003_121114-2.jpg": "",
        f"{swallow_assets2}/20251003_121417.jpg": "",
        f"{arzhang_assets2}/20251005_112250.jpg": "",
        f"{arzhang_assets2}/20251005_112332.jpg": "",
        f"{arzhang_assets2}/20251005_112530.jpg": "",
        f"{arzhang_assets2}/20251018_213230.jpg": "",
    }
)
